@@ -26,11 +26,107 @@
 
 use std::sync::{Arc, Mutex, MutexGuard, OnceLock};
 
-use super::tests::Ty;
 use crate::db::tests::{setup_db, TestDb};
-use crate::types::KnownClass;
+use crate::types::{
+    builtins_symbol, known_module_symbol, IntersectionBuilder, KnownClass, KnownInstanceType,
+    SubclassOfType, TupleType, Type, UnionType,
+};
+use crate::KnownModule;
 use quickcheck::{Arbitrary, Gen};
 
+/// A test representation of a type that can be transformed unambiguously into a real Type,
+/// given a db.
+#[derive(Debug, Clone, PartialEq)]
+pub(crate) enum Ty {
+    Never,
+    Unknown,
+    None,
+    Any,
+    IntLiteral(i64),
+    BooleanLiteral(bool),
+    StringLiteral(&'static str),
+    LiteralString,
+    BytesLiteral(&'static str),
+    // BuiltinInstance("str") corresponds to an instance of the builtin `str` class
+    BuiltinInstance(&'static str),
+    /// Members of the `abc` stdlib module
+    AbcInstance(&'static str),
+    AbcClassLiteral(&'static str),
+    TypingLiteral,
+    // BuiltinClassLiteral("str") corresponds to the builtin `str` class object itself
+    BuiltinClassLiteral(&'static str),
+    KnownClassInstance(KnownClass),
+    Union(Vec<Ty>),
+    Intersection {
+        pos: Vec<Ty>,
+        neg: Vec<Ty>,
+    },
+    Tuple(Vec<Ty>),
+    SubclassOfAny,
+    SubclassOfBuiltinClass(&'static str),
+    SubclassOfAbcClass(&'static str),
+    AlwaysTruthy,
+    AlwaysFalsy,
+}
+
+impl Ty {
+    pub(crate) fn into_type(self, db: &TestDb) -> Type<'_> {
+        match self {
+            Ty::Never => Type::Never,
+            Ty::Unknown => Type::unknown(),
+            Ty::None => Type::none(db),
+            Ty::Any => Type::any(),
+            Ty::IntLiteral(n) => Type::IntLiteral(n),
+            Ty::StringLiteral(s) => Type::string_literal(db, s),
+            Ty::BooleanLiteral(b) => Type::BooleanLiteral(b),
+            Ty::LiteralString => Type::LiteralString,
+            Ty::BytesLiteral(s) => Type::bytes_literal(db, s.as_bytes()),
+            Ty::BuiltinInstance(s) => builtins_symbol(db, s).expect_type().to_instance(db),
+            Ty::AbcInstance(s) => known_module_symbol(db, KnownModule::Abc, s)
+                .expect_type()
+                .to_instance(db),
+            Ty::AbcClassLiteral(s) => known_module_symbol(db, KnownModule::Abc, s).expect_type(),
+            Ty::TypingLiteral => Type::KnownInstance(KnownInstanceType::Literal),
+            Ty::BuiltinClassLiteral(s) => builtins_symbol(db, s).expect_type(),
+            Ty::KnownClassInstance(known_class) => known_class.to_instance(db),
+            Ty::Union(tys) => {
+                UnionType::from_elements(db, tys.into_iter().map(|ty| ty.into_type(db)))
+            }
+            Ty::Intersection { pos, neg } => {
+                let mut builder = IntersectionBuilder::new(db);
+                for p in pos {
+                    builder = builder.add_positive(p.into_type(db));
+                }
+                for n in neg {
+                    builder = builder.add_negative(n.into_type(db));
+                }
+                builder.build()
+            }
+            Ty::Tuple(tys) => {
+                let elements = tys.into_iter().map(|ty| ty.into_type(db));
+                TupleType::from_elements(db, elements)
+            }
+            Ty::SubclassOfAny => SubclassOfType::subclass_of_any(),
+            Ty::SubclassOfBuiltinClass(s) => SubclassOfType::from(
+                db,
+                builtins_symbol(db, s)
+                    .expect_type()
+                    .expect_class_literal()
+                    .class,
+            ),
+            Ty::SubclassOfAbcClass(s) => SubclassOfType::from(
+                db,
+                known_module_symbol(db, KnownModule::Abc, s)
+                    .expect_type()
+                    .expect_class_literal()
+                    .class,
+            ),
+            Ty::AlwaysTruthy => Type::AlwaysTruthy,
+            Ty::AlwaysFalsy => Type::AlwaysFalsy,
+        }
+    }
+}
+
 fn arbitrary_core_type(g: &mut Gen) -> Ty {
     // We could select a random integer here, but this would make it much less
     // likely to explore interesting edge cases:
@@ -205,7 +301,7 @@ macro_rules! type_property_test {
     ($test_name:ident, $db:ident, forall types $($types:ident),+ . $property:expr) => {
         #[quickcheck_macros::quickcheck]
         #[ignore]
-        fn $test_name($($types: crate::types::tests::Ty),+) -> bool {
+        fn $test_name($($types: super::Ty),+) -> bool {
             let db_cached = super::get_cached_db();
             let $db = &*db_cached;
             $(let $types = $types.into_type($db);)+
@@ -219,16 +315,48 @@ macro_rules! type_property_test {
     };
 }
 
+fn intersection<'db>(db: &'db TestDb, tys: impl IntoIterator<Item = Type<'db>>) -> Type<'db> {
+    let mut builder = IntersectionBuilder::new(db);
+    for ty in tys {
+        builder = builder.add_positive(ty);
+    }
+    builder.build()
+}
+
+fn union<'db>(db: &'db TestDb, tys: impl IntoIterator<Item = Type<'db>>) -> Type<'db> {
+    UnionType::from_elements(db, tys)
+}
+
 mod stable {
+    use super::union;
     use crate::types::{KnownClass, Type};
 
-    // `T` is equivalent to itself.
+    // Reflexivity: `T` is equivalent to itself.
     type_property_test!(
         equivalent_to_is_reflexive, db,
         forall types t. t.is_fully_static(db) => t.is_equivalent_to(db, t)
     );
 
-    // `T` is a subtype of itself.
+    // Symmetry: If `S` is equivalent to `T`, then `T` must be equivalent to `S`.
+    // Note that this (trivially) holds true for gradual types as well.
+    type_property_test!(
+        equivalent_to_is_symmetric, db,
+        forall types s, t. s.is_equivalent_to(db, t) => t.is_equivalent_to(db, s)
+    );
+
+    // Transitivity: If `S` is equivalent to `T` and `T` is equivalent to `U`, then `S` must be equivalent to `U`.
+    type_property_test!(
+        equivalent_to_is_transitive, db,
+        forall types s, t, u. s.is_equivalent_to(db, t) && t.is_equivalent_to(db, u) => s.is_equivalent_to(db, u)
+    );
+
+    // Symmetry: If `S` is gradual equivalent to `T`, `T` is gradual equivalent to `S`.
+    type_property_test!(
+        gradual_equivalent_to_is_symmetric, db,
+        forall types s, t. s.is_gradual_equivalent_to(db, t) => t.is_gradual_equivalent_to(db, s)
+    );
+
+    // A fully static type `T` is a subtype of itself.
     type_property_test!(
         subtype_of_is_reflexive, db,
         forall types t. t.is_fully_static(db) => t.is_subtype_of(db, t)
@@ -240,6 +368,12 @@ mod stable {
         forall types s, t, u. s.is_subtype_of(db, t) && t.is_subtype_of(db, u) => s.is_subtype_of(db, u)
     );
 
+    // `S <: T` and `T <: S` implies that `S` is equivalent to `T`.
+    type_property_test!(
+        subtype_of_is_antisymmetric, db,
+        forall types s, t. s.is_subtype_of(db, t) && t.is_subtype_of(db, s) => s.is_equivalent_to(db, t)
+    );
+
     // `T` is not disjoint from itself, unless `T` is `Never`.
     type_property_test!(
         disjoint_from_is_irreflexive, db,
@@ -305,6 +439,41 @@ mod stable {
         never_subtype_of_every_fully_static_type, db,
         forall types t. t.is_fully_static(db) => Type::Never.is_subtype_of(db, t)
     );
+
+    // For any two fully static types, each type in the pair must be a subtype of their union.
+    type_property_test!(
+        all_fully_static_type_pairs_are_subtype_of_their_union, db,
+        forall types s, t.
+            s.is_fully_static(db) && t.is_fully_static(db)
+            => s.is_subtype_of(db, union(db, [s, t])) && t.is_subtype_of(db, union(db, [s, t]))
+    );
+
+    // A fully static type does not have any materializations.
+    // Thus, two equivalent (fully static) types are also gradual equivalent.
+    type_property_test!(
+        two_equivalent_types_are_also_gradual_equivalent, db,
+        forall types s, t. s.is_equivalent_to(db, t) => s.is_gradual_equivalent_to(db, t)
+    );
+
+    // Two gradual equivalent fully static types are also equivalent.
+    type_property_test!(
+        two_gradual_equivalent_fully_static_types_are_also_equivalent, db,
+        forall types s, t.
+            s.is_fully_static(db) && s.is_gradual_equivalent_to(db, t) => s.is_equivalent_to(db, t)
+    );
+
+    // `T` can be assigned to itself.
+    type_property_test!(
+        assignable_to_is_reflexive, db,
+        forall types t. t.is_assignable_to(db, t)
+    );
+
+    // For *any* pair of types, whether fully static or not,
+    // each of the pair should be assignable to the union of the two.
+    type_property_test!(
+        all_type_pairs_are_assignable_to_their_union, db,
+        forall types s, t. s.is_assignable_to(db, union(db, [s, t])) && t.is_assignable_to(db, union(db, [s, t]))
+    );
 }
 
 /// This module contains property tests that currently lead to many false positives.
@@ -315,41 +484,77 @@ mod stable {
 /// tests to the `stable` section. In the meantime, it can still be useful to run these
 /// tests (using [`types::property_tests::flaky`]), to see if there are any new obvious bugs.
 mod flaky {
-    use crate::{
-        db::tests::TestDb,
-        types::{IntersectionBuilder, Type},
-    };
+    use itertools::Itertools;
 
-    // Currently fails due to https://github.com/astral-sh/ruff/issues/14899
-    // `T` can be assigned to itself.
-    type_property_test!(
-        assignable_to_is_reflexive, db,
-        forall types t. t.is_assignable_to(db, t)
-    );
-
-    // Currently fails due to https://github.com/astral-sh/ruff/issues/14899
-    // An intersection of two types should be assignable to both of them
-    fn intersection<'db>(db: &'db TestDb, s: Type<'db>, t: Type<'db>) -> Type<'db> {
-        IntersectionBuilder::new(db)
-            .add_positive(s)
-            .add_positive(t)
-            .build()
-    }
-
-    type_property_test!(
-        intersection_assignable_to_both, db,
-        forall types s, t. intersection(db, s, t).is_assignable_to(db, s) && intersection(db, s, t).is_assignable_to(db, t)
-    );
-
-    // `S <: T` and `T <: S` implies that `S` is equivalent to `T`.
-    type_property_test!(
-        subtype_of_is_antisymmetric, db,
-        forall types s, t. s.is_subtype_of(db, t) && t.is_subtype_of(db, s) => s.is_equivalent_to(db, t)
-    );
+    use super::{intersection, union};
 
     // Negating `T` twice is equivalent to `T`.
     type_property_test!(
         double_negation_is_identity, db,
         forall types t. t.negate(db).negate(db).is_equivalent_to(db, t)
     );
+
+    // ~T should be disjoint from T
+    type_property_test!(
+        negation_is_disjoint, db,
+        forall types t. t.is_fully_static(db) => t.negate(db).is_disjoint_from(db, t)
+    );
+
+    // If `S <: T`, then `~T <: ~S`.
+    type_property_test!(
+        negation_reverses_subtype_order, db,
+        forall types s, t. s.is_subtype_of(db, t) => t.negate(db).is_subtype_of(db, s.negate(db))
+    );
+
+    // For two fully static types, their intersection must be a subtype of each type in the pair.
+    type_property_test!(
+        all_fully_static_type_pairs_are_supertypes_of_their_intersection, db,
+        forall types s, t.
+            s.is_fully_static(db) && t.is_fully_static(db)
+            => intersection(db, [s, t]).is_subtype_of(db, s) && intersection(db, [s, t]).is_subtype_of(db, t)
+    );
+
+    // And for non-fully-static types, the intersection of a pair of types
+    // should be assignable to both types of the pair.
+    // Currently fails due to https://github.com/astral-sh/ruff/issues/14899
+    type_property_test!(
+        all_type_pairs_can_be_assigned_from_their_intersection, db,
+        forall types s, t. intersection(db, [s, t]).is_assignable_to(db, s) && intersection(db, [s, t]).is_assignable_to(db, t)
+    );
+
+    // Equal element sets of intersections implies equivalence
+    // flaky at least in part because of https://github.com/astral-sh/ruff/issues/15513
+    type_property_test!(
+        intersection_equivalence_not_order_dependent, db,
+        forall types s, t, u.
+            s.is_fully_static(db) && t.is_fully_static(db) && u.is_fully_static(db)
+            => [s, t, u]
+                .into_iter()
+                .permutations(3)
+                .map(|trio_of_types| intersection(db, trio_of_types))
+                .permutations(2)
+                .all(|vec_of_intersections| vec_of_intersections[0].is_equivalent_to(db, vec_of_intersections[1]))
+    );
+
+    // Equal element sets of unions implies equivalence
+    // flaky at laest in part because of https://github.com/astral-sh/ruff/issues/15513
+    type_property_test!(
+        union_equivalence_not_order_dependent, db,
+        forall types s, t, u.
+            s.is_fully_static(db) && t.is_fully_static(db) && u.is_fully_static(db)
+            => [s, t, u]
+                .into_iter()
+                .permutations(3)
+                .map(|trio_of_types| union(db, trio_of_types))
+                .permutations(2)
+                .all(|vec_of_unions| vec_of_unions[0].is_equivalent_to(db, vec_of_unions[1]))
+    );
+
+    // `S | T` is always a supertype of `S`.
+    // Thus, `S` is never disjoint from `S | T`.
+    type_property_test!(
+        constituent_members_of_union_is_not_disjoint_from_that_union, db,
+        forall types s, t.
+            !s.is_disjoint_from(db, union(db, [s, t])) && !t.is_disjoint_from(db, union(db, [s, t]))
+    );
 }
