@@ -385,8 +385,8 @@ mod tests {
             self.message.into()
         }
 
-        fn file(&self) -> File {
-            self.file
+        fn file(&self) -> Option<File> {
+            Some(self.file)
         }
 
         fn range(&self) -> Option<TextRange> {
