@@ -5,7 +5,7 @@ use crate::codes::Rule;
 use crate::rules::{flake8_simplify, pylint, refurb};
 
 /// Run lint rules over a [`Comprehension`] syntax nodes.
-pub(crate) fn comprehension(comprehension: &Comprehension, checker: &mut Checker) {
+pub(crate) fn comprehension(comprehension: &Comprehension, checker: &Checker) {
     if checker.enabled(Rule::InDictKeys) {
         flake8_simplify::rules::key_in_dict_comprehension(checker, comprehension);
     }
