@@ -14,7 +14,8 @@ mod tests {
     use crate::{assert_messages, settings};
 
     #[test_case(Rule::FastApiRedundantResponseModel, Path::new("FAST001.py"))]
-    #[test_case(Rule::FastApiNonAnnotatedDependency, Path::new("FAST002.py"))]
+    #[test_case(Rule::FastApiNonAnnotatedDependency, Path::new("FAST002_0.py"))]
+    #[test_case(Rule::FastApiNonAnnotatedDependency, Path::new("FAST002_1.py"))]
     #[test_case(Rule::FastApiUnusedPathParameter, Path::new("FAST003.py"))]
     fn rules(rule_code: Rule, path: &Path) -> Result<()> {
         let snapshot = format!("{}_{}", rule_code.as_ref(), path.to_string_lossy());
@@ -28,7 +29,8 @@ mod tests {
 
     // FAST002 autofixes use `typing_extensions` on Python 3.8,
     // since `typing.Annotated` was added in Python 3.9
-    #[test_case(Rule::FastApiNonAnnotatedDependency, Path::new("FAST002.py"))]
+    #[test_case(Rule::FastApiNonAnnotatedDependency, Path::new("FAST002_0.py"))]
+    #[test_case(Rule::FastApiNonAnnotatedDependency, Path::new("FAST002_1.py"))]
     fn rules_py38(rule_code: Rule, path: &Path) -> Result<()> {
         let snapshot = format!("{}_{}_py38", rule_code.as_ref(), path.to_string_lossy());
         let diagnostics = test_path(
