@@ -16,6 +16,8 @@ mod tests {
     use crate::settings::LinterSettings;
     use crate::test::test_path;
 
+    use crate::settings::types::PythonVersion;
+
     #[test_case(Rule::AbstractBaseClassWithoutAbstractMethod, Path::new("B024.py"))]
     #[test_case(Rule::AssertFalse, Path::new("B011.py"))]
     #[test_case(Rule::AssertRaisesException, Path::new("B017.py"))]
@@ -78,6 +80,34 @@ mod tests {
         Ok(())
     }
 
+    #[test_case(
+        Rule::ClassAsDataStructure,
+        Path::new("class_as_data_structure.py"),
+        PythonVersion::Py39
+    )]
+    fn rules_with_target_version(
+        rule_code: Rule,
+        path: &Path,
+        target_version: PythonVersion,
+    ) -> Result<()> {
+        let snapshot = format!(
+            "{}_py{}{}_{}",
+            rule_code.noqa_code(),
+            target_version.major(),
+            target_version.minor(),
+            path.to_string_lossy(),
+        );
+        let diagnostics = test_path(
+            Path::new("flake8_bugbear").join(path).as_path(),
+            &LinterSettings {
+                target_version,
+                ..LinterSettings::for_rule(rule_code)
+            },
+        )?;
+        assert_messages!(snapshot, diagnostics);
+        Ok(())
+    }
+
     #[test]
     fn zip_without_explicit_strict() -> Result<()> {
         let snapshot = "B905.py";
