@@ -91,7 +91,7 @@ impl Violation for ReturnInGenerator {
 }
 
 /// B901
-pub(crate) fn return_in_generator(checker: &mut Checker, function_def: &StmtFunctionDef) {
+pub(crate) fn return_in_generator(checker: &Checker, function_def: &StmtFunctionDef) {
     if function_def.name.id == "__await__" {
         return;
     }
@@ -101,9 +101,7 @@ pub(crate) fn return_in_generator(checker: &mut Checker, function_def: &StmtFunc
 
     if visitor.has_yield {
         if let Some(return_) = visitor.return_ {
-            checker
-                .diagnostics
-                .push(Diagnostic::new(ReturnInGenerator, return_));
+            checker.report_diagnostic(Diagnostic::new(ReturnInGenerator, return_));
         }
     }
 }
