@@ -1,6 +1,7 @@
 use ruff_diagnostics::{AlwaysFixableViolation, Diagnostic, Edit, Fix};
 use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_python_ast as ast;
+use ruff_python_ast::parenthesize::parenthesized_range;
 use ruff_text_size::{Ranged, TextSize};
 
 use crate::checkers::ast::Checker;
@@ -43,7 +44,7 @@ impl AlwaysFixableViolation for UnnecessaryListComprehensionSet {
 }
 
 /// C403 (`set([...])`)
-pub(crate) fn unnecessary_list_comprehension_set(checker: &mut Checker, call: &ast::ExprCall) {
+pub(crate) fn unnecessary_list_comprehension_set(checker: &Checker, call: &ast::ExprCall) {
     let Some(argument) = helpers::exactly_one_argument_with_matching_function(
         "set",
         &call.func,
@@ -55,32 +56,39 @@ pub(crate) fn unnecessary_list_comprehension_set(checker: &mut Checker, call: &a
     if !checker.semantic().has_builtin_binding("set") {
         return;
     }
-    if argument.is_list_comp_expr() {
-        let diagnostic = Diagnostic::new(UnnecessaryListComprehensionSet, call.range());
-        let fix = {
-            // Replace `set(` with `{`.
-            let call_start = Edit::replacement(
-                pad_start("{", call.range(), checker.locator(), checker.semantic()),
-                call.start(),
-                call.arguments.start() + TextSize::from(1),
-            );
-
-            // Replace `)` with `}`.
-            let call_end = Edit::replacement(
-                pad_end("}", call.range(), checker.locator(), checker.semantic()),
-                call.arguments.end() - TextSize::from(1),
-                call.end(),
-            );
-
-            // Delete the open bracket (`[`).
-            let argument_start =
-                Edit::deletion(argument.start(), argument.start() + TextSize::from(1));
-
-            // Delete the close bracket (`]`).
-            let argument_end = Edit::deletion(argument.end() - TextSize::from(1), argument.end());
-
-            Fix::unsafe_edits(call_start, [argument_start, argument_end, call_end])
-        };
-        checker.diagnostics.push(diagnostic.with_fix(fix));
+    if !argument.is_list_comp_expr() {
+        return;
     }
+    let diagnostic = Diagnostic::new(UnnecessaryListComprehensionSet, call.range());
+    let one = TextSize::from(1);
+
+    // Replace `set(` with `{`.
+    let call_start = Edit::replacement(
+        pad_start("{", call.range(), checker.locator(), checker.semantic()),
+        call.start(),
+        call.arguments.start() + one,
+    );
+
+    // Replace `)` with `}`.
+    let call_end = Edit::replacement(
+        pad_end("}", call.range(), checker.locator(), checker.semantic()),
+        call.arguments.end() - one,
+        call.end(),
+    );
+
+    // If the list comprehension is parenthesized, remove the parentheses in addition to
+    // removing the brackets.
+    let replacement_range = parenthesized_range(
+        argument.into(),
+        (&call.arguments).into(),
+        checker.comment_ranges(),
+        checker.locator().contents(),
+    )
+    .unwrap_or_else(|| argument.range());
+
+    let span = argument.range().add_start(one).sub_end(one);
+    let replacement =
+        Edit::range_replacement(checker.source()[span].to_string(), replacement_range);
+    let fix = Fix::unsafe_edits(call_start, [call_end, replacement]);
+    checker.report_diagnostic(diagnostic.with_fix(fix));
 }
