@@ -52,10 +52,13 @@ impl AlwaysFixableViolation for UnnecessaryLiteralWithinDictCall {
 }
 
 /// C418
-pub(crate) fn unnecessary_literal_within_dict_call(checker: &mut Checker, call: &ast::ExprCall) {
+pub(crate) fn unnecessary_literal_within_dict_call(checker: &Checker, call: &ast::ExprCall) {
     if !call.arguments.keywords.is_empty() {
         return;
     }
+    if call.arguments.args.len() > 1 {
+        return;
+    }
     let Some(argument) =
         helpers::first_argument_with_matching_function("dict", &call.func, &call.arguments.args)
     else {
@@ -86,7 +89,7 @@ pub(crate) fn unnecessary_literal_within_dict_call(checker: &mut Checker, call:
         Fix::unsafe_edits(call_start, [call_end])
     });
 
-    checker.diagnostics.push(diagnostic);
+    checker.report_diagnostic(diagnostic);
 }
 
 #[derive(Debug, Copy, Clone, PartialEq, Eq)]
