@@ -116,7 +116,7 @@ enum ErrorKind {
 }
 
 /// PYI036
-pub(crate) fn bad_exit_annotation(checker: &mut Checker, function: &StmtFunctionDef) {
+pub(crate) fn bad_exit_annotation(checker: &Checker, function: &StmtFunctionDef) {
     let StmtFunctionDef {
         is_async,
         decorator_list,
@@ -167,7 +167,7 @@ pub(crate) fn bad_exit_annotation(checker: &mut Checker, function: &StmtFunction
         .skip(3)
         .filter(|parameter| parameter.default.is_none())
     {
-        checker.diagnostics.push(Diagnostic::new(
+        checker.report_diagnostic(Diagnostic::new(
             BadExitAnnotation {
                 func_kind,
                 error_kind: ErrorKind::ArgsAfterFirstFourMustHaveDefault,
@@ -182,7 +182,7 @@ pub(crate) fn bad_exit_annotation(checker: &mut Checker, function: &StmtFunction
         .iter()
         .filter(|arg| arg.default.is_none())
     {
-        checker.diagnostics.push(Diagnostic::new(
+        checker.report_diagnostic(Diagnostic::new(
             BadExitAnnotation {
                 func_kind,
                 error_kind: ErrorKind::AllKwargsMustHaveDefault,
@@ -196,11 +196,10 @@ pub(crate) fn bad_exit_annotation(checker: &mut Checker, function: &StmtFunction
 
 /// Determine whether a "short" argument list (i.e., an argument list with less than four elements)
 /// contains a star-args argument annotated with `object`. If not, report an error.
-fn check_short_args_list(checker: &mut Checker, parameters: &Parameters, func_kind: FuncKind) {
+fn check_short_args_list(checker: &Checker, parameters: &Parameters, func_kind: FuncKind) {
     if let Some(varargs) = &parameters.vararg {
         if let Some(annotation) = varargs
-            .annotation
-            .as_ref()
+            .annotation()
             .filter(|ann| !is_object_or_unused(ann, checker.semantic()))
         {
             let mut diagnostic = Diagnostic::new(
@@ -221,10 +220,10 @@ fn check_short_args_list(checker: &mut Checker, parameters: &Parameters, func_ki
                 Ok(Fix::safe_edits(binding_edit, import_edit))
             });
 
-            checker.diagnostics.push(diagnostic);
+            checker.report_diagnostic(diagnostic);
         }
     } else {
-        checker.diagnostics.push(Diagnostic::new(
+        checker.report_diagnostic(Diagnostic::new(
             BadExitAnnotation {
                 func_kind,
                 error_kind: ErrorKind::MissingArgs,
@@ -237,8 +236,8 @@ fn check_short_args_list(checker: &mut Checker, parameters: &Parameters, func_ki
 /// Determines whether the positional arguments of an `__exit__` or `__aexit__` method
 /// (that is not decorated with `@typing.overload`) are annotated correctly.
 fn check_positional_args_for_non_overloaded_method(
-    checker: &mut Checker,
-    non_self_positional_args: &[&ParameterWithDefault],
+    checker: &Checker,
+    non_self_positional_params: &[&ParameterWithDefault],
     kind: FuncKind,
 ) {
     // For each argument, define the predicate against which to check the annotation.
@@ -252,8 +251,10 @@ fn check_positional_args_for_non_overloaded_method(
         (ErrorKind::ThirdArgBadAnnotation, is_traceback_type),
     ];
 
-    for (arg, (error_info, predicate)) in non_self_positional_args.iter().take(3).zip(validations) {
-        let Some(annotation) = arg.parameter.annotation.as_ref() else {
+    for (param, (error_info, predicate)) in
+        non_self_positional_params.iter().take(3).zip(validations)
+    {
+        let Some(annotation) = param.annotation() else {
             continue;
         };
 
@@ -269,7 +270,7 @@ fn check_positional_args_for_non_overloaded_method(
             continue;
         }
 
-        checker.diagnostics.push(Diagnostic::new(
+        checker.report_diagnostic(Diagnostic::new(
             BadExitAnnotation {
                 func_kind: kind,
                 error_kind: error_info,
@@ -282,7 +283,7 @@ fn check_positional_args_for_non_overloaded_method(
 /// Determines whether the positional arguments of an `__exit__` or `__aexit__` method
 /// overload are annotated correctly.
 fn check_positional_args_for_overloaded_method(
-    checker: &mut Checker,
+    checker: &Checker,
     non_self_positional_args: &[&ParameterWithDefault],
     kind: FuncKind,
     parent_class_def: &StmtClassDef,
@@ -293,13 +294,9 @@ fn check_positional_args_for_overloaded_method(
         predicate: impl FnOnce(&Expr) -> bool,
         semantic: &SemanticModel,
     ) -> bool {
-        parameter
-            .parameter
-            .annotation
-            .as_ref()
-            .map_or(true, |annotation| {
-                predicate(annotation) || is_object_or_unused(annotation, semantic)
-            })
+        parameter.annotation().map_or(true, |annotation| {
+            predicate(annotation) || is_object_or_unused(annotation, semantic)
+        })
     }
 
     let semantic = checker.semantic();
@@ -412,7 +409,7 @@ fn check_positional_args_for_overloaded_method(
     }
 
     // Okay, neither of them match...
-    checker.diagnostics.push(Diagnostic::new(
+    checker.report_diagnostic(Diagnostic::new(
         BadExitAnnotation {
             func_kind: kind,
             error_kind: ErrorKind::UnrecognizedExitOverload,
