@@ -7,7 +7,7 @@ pub(crate) use bytestring_usage::*;
 pub(crate) use collections_named_tuple::*;
 pub(crate) use complex_assignment_in_stub::*;
 pub(crate) use complex_if_statement_in_stub::*;
-pub(crate) use custom_type_var_return_type::*;
+pub(crate) use custom_type_var_for_self::*;
 pub(crate) use docstring_in_stubs::*;
 pub(crate) use duplicate_literal_member::*;
 pub(crate) use duplicate_union_member::*;
@@ -50,7 +50,7 @@ mod bytestring_usage;
 mod collections_named_tuple;
 mod complex_assignment_in_stub;
 mod complex_if_statement_in_stub;
-mod custom_type_var_return_type;
+mod custom_type_var_for_self;
 mod docstring_in_stubs;
 mod duplicate_literal_member;
 mod duplicate_union_member;
