@@ -54,10 +54,7 @@ impl Violation for Pep484StylePositionalOnlyParameter {
 }
 
 /// PYI063
-pub(crate) fn pep_484_positional_parameter(
-    checker: &mut Checker,
-    function_def: &ast::StmtFunctionDef,
-) {
+pub(crate) fn pep_484_positional_parameter(checker: &Checker, function_def: &ast::StmtFunctionDef) {
     // PEP 570 was introduced in Python 3.8.
     if checker.settings.target_version < PythonVersion::Py38 {
         return;
@@ -90,7 +87,7 @@ pub(crate) fn pep_484_positional_parameter(
 
     if let Some(arg) = function_def.parameters.args.get(skip) {
         if is_old_style_positional_only(arg) {
-            checker.diagnostics.push(Diagnostic::new(
+            checker.report_diagnostic(Diagnostic::new(
                 Pep484StylePositionalOnlyParameter,
                 arg.identifier(),
             ));
@@ -100,7 +97,7 @@ pub(crate) fn pep_484_positional_parameter(
 
 /// Returns `true` if the [`ParameterWithDefault`] is an old-style positional-only parameter (i.e.,
 /// its name starts with `__` and does not end with `__`).
-fn is_old_style_positional_only(arg: &ParameterWithDefault) -> bool {
-    let arg_name = &arg.parameter.name;
+fn is_old_style_positional_only(param: &ParameterWithDefault) -> bool {
+    let arg_name = param.name();
     arg_name.starts_with("__") && !arg_name.ends_with("__")
 }
