@@ -59,7 +59,7 @@ impl Violation for UnprefixedTypeParam {
 }
 
 /// PYI001
-pub(crate) fn prefix_type_params(checker: &mut Checker, value: &Expr, targets: &[Expr]) {
+pub(crate) fn prefix_type_params(checker: &Checker, value: &Expr, targets: &[Expr]) {
     // If the typing modules were never imported, we'll never match below.
     if !checker.semantic().seen_typing() {
         return;
@@ -106,7 +106,5 @@ pub(crate) fn prefix_type_params(checker: &mut Checker, value: &Expr, targets: &
         return;
     };
 
-    checker
-        .diagnostics
-        .push(Diagnostic::new(UnprefixedTypeParam { kind }, value.range()));
+    checker.report_diagnostic(Diagnostic::new(UnprefixedTypeParam { kind }, value.range()));
 }
