@@ -50,7 +50,7 @@ impl AlwaysFixableViolation for AvoidableEscapedQuote {
 }
 
 /// Q003
-pub(crate) fn avoidable_escaped_quote(checker: &mut Checker, string_like: StringLike) {
+pub(crate) fn avoidable_escaped_quote(checker: &Checker, string_like: StringLike) {
     if checker.semantic().in_pep_257_docstring()
         || checker.semantic().in_string_type_definition()
         // This rule has support for strings nested inside another f-strings but they're checked
@@ -75,7 +75,7 @@ pub(crate) fn avoidable_escaped_quote(checker: &mut Checker, string_like: String
         }
     }
 
-    checker.diagnostics.extend(rule_checker.into_diagnostics());
+    checker.report_diagnostics(rule_checker.into_diagnostics());
 }
 
 /// Checks for `Q003` violations using the [`Visitor`] implementation.
