@@ -47,7 +47,7 @@ impl AlwaysFixableViolation for EmptyTypeCheckingBlock {
 }
 
 /// TC005
-pub(crate) fn empty_type_checking_block(checker: &mut Checker, stmt: &ast::StmtIf) {
+pub(crate) fn empty_type_checking_block(checker: &Checker, stmt: &ast::StmtIf) {
     if !typing::is_type_checking_block(stmt, checker.semantic()) {
         return;
     }
@@ -71,5 +71,5 @@ pub(crate) fn empty_type_checking_block(checker: &mut Checker, stmt: &ast::StmtI
     diagnostic.set_fix(Fix::safe_edit(edit).isolate(Checker::isolation(
         checker.semantic().current_statement_parent_id(),
     )));
-    checker.diagnostics.push(diagnostic);
+    checker.report_diagnostic(diagnostic);
 }
