@@ -57,7 +57,7 @@ impl AlwaysFixableViolation for RuntimeCastValue {
 }
 
 /// TC006
-pub(crate) fn runtime_cast_value(checker: &mut Checker, type_expr: &Expr) {
+pub(crate) fn runtime_cast_value(checker: &Checker, type_expr: &Expr) {
     if type_expr.is_string_literal_expr() {
         return;
     }
@@ -68,14 +68,12 @@ pub(crate) fn runtime_cast_value(checker: &mut Checker, type_expr: &Expr) {
         checker.semantic(),
         checker.stylist(),
         checker.locator(),
+        checker.default_string_flags(),
     );
-    if checker
-        .comment_ranges()
-        .has_comments(type_expr, checker.source())
-    {
+    if checker.comment_ranges().intersects(type_expr.range()) {
         diagnostic.set_fix(Fix::unsafe_edit(edit));
     } else {
         diagnostic.set_fix(Fix::safe_edit(edit));
     }
-    checker.diagnostics.push(diagnostic);
+    checker.report_diagnostic(diagnostic);
 }
