@@ -1,4 +1,3 @@
-use crate::registry::Rule;
 use ast::{ExprContext, Operator};
 use ruff_diagnostics::{AlwaysFixableViolation, Diagnostic, Edit, Fix, FixAvailability, Violation};
 use ruff_macros::{derive_message_formats, ViolationMetadata};
@@ -9,7 +8,10 @@ use ruff_python_stdlib::typing::{is_pep_593_generic_type, is_standard_library_li
 use ruff_text_size::Ranged;
 
 use crate::checkers::ast::Checker;
+use crate::registry::Rule;
 use crate::rules::flake8_type_checking::helpers::quote_type_expression;
+use crate::settings::types::PythonVersion;
+use crate::settings::LinterSettings;
 
 /// ## What it does
 /// Checks if [PEP 613] explicit type aliases contain references to
@@ -111,9 +113,9 @@ impl Violation for UnquotedTypeAlias {
 /// This rule only applies to type aliases in non-stub files. For removing quotes in other
 /// contexts or in stub files, see:
 ///
-/// - [`quoted-annotation-in-stub`](quoted-annotation-in-stub.md): A rule that
+/// - [`quoted-annotation-in-stub`][PYI020]: A rule that
 ///   removes all quoted annotations from stub files
-/// - [`quoted-annotation`](quoted-annotation.md): A rule that removes unnecessary quotes
+/// - [`quoted-annotation`][UP037]: A rule that removes unnecessary quotes
 ///   from *annotations* in runtime files.
 ///
 /// ## References
@@ -124,6 +126,8 @@ impl Violation for UnquotedTypeAlias {
 /// [PEP 604]: https://peps.python.org/pep-0604/
 /// [PEP 613]: https://peps.python.org/pep-0613/
 /// [PEP 695]: https://peps.python.org/pep-0695/#generic-type-alias
+/// [PYI020]: https://docs.astral.sh/ruff/rules/quoted-annotation-in-stub/
+/// [UP037]: https://docs.astral.sh/ruff/rules/quoted-annotation/
 #[derive(ViolationMetadata)]
 pub(crate) struct QuotedTypeAlias;
 
@@ -173,6 +177,7 @@ pub(crate) fn unquoted_type_alias(checker: &Checker, binding: &Binding) -> Optio
         checker.semantic(),
         checker.stylist(),
         checker.locator(),
+        checker.default_string_flags(),
     );
     let mut diagnostics = Vec::with_capacity(names.len());
     for name in names {
@@ -262,7 +267,7 @@ fn collect_typing_references<'a>(
 
 /// TC008
 pub(crate) fn quoted_type_alias(
-    checker: &mut Checker,
+    checker: &Checker,
     expr: &Expr,
     annotation_expr: &ast::ExprStringLiteral,
 ) {
@@ -279,7 +284,7 @@ pub(crate) fn quoted_type_alias(
 
     // explicit type aliases require some additional checks to avoid false positives
     if checker.semantic().in_annotated_type_alias_value()
-        && quotes_are_unremovable(checker.semantic(), expr)
+        && quotes_are_unremovable(checker.semantic(), expr, checker.settings)
     {
         return;
     }
@@ -287,29 +292,45 @@ pub(crate) fn quoted_type_alias(
     let range = annotation_expr.range();
     let mut diagnostic = Diagnostic::new(QuotedTypeAlias, range);
     let edit = Edit::range_replacement(annotation_expr.value.to_string(), range);
-    if checker
-        .comment_ranges()
-        .has_comments(expr, checker.source())
-    {
+    if checker.comment_ranges().intersects(range) {
         diagnostic.set_fix(Fix::unsafe_edit(edit));
     } else {
         diagnostic.set_fix(Fix::safe_edit(edit));
     }
-    checker.diagnostics.push(diagnostic);
+    checker.report_diagnostic(diagnostic);
 }
 
 /// Traverses the type expression and checks if the expression can safely
 /// be unquoted
-fn quotes_are_unremovable(semantic: &SemanticModel, expr: &Expr) -> bool {
+fn quotes_are_unremovable(
+    semantic: &SemanticModel,
+    expr: &Expr,
+    settings: &LinterSettings,
+) -> bool {
     match expr {
-        Expr::BinOp(ast::ExprBinOp { left, right, .. }) => {
-            quotes_are_unremovable(semantic, left) || quotes_are_unremovable(semantic, right)
+        Expr::BinOp(ast::ExprBinOp {
+            left, right, op, ..
+        }) => {
+            match op {
+                Operator::BitOr => {
+                    if settings.target_version < PythonVersion::Py310 {
+                        return true;
+                    }
+                    quotes_are_unremovable(semantic, left, settings)
+                        || quotes_are_unremovable(semantic, right, settings)
+                }
+                // for now we'll treat uses of other operators as unremovable quotes
+                // since that would make it an invalid type expression anyways. We skip
+                // walking the nested non-type expressions from `typing.Annotated`, so
+                // we don't produce false negatives in this branch.
+                _ => true,
+            }
         }
         Expr::Starred(ast::ExprStarred {
             value,
             ctx: ExprContext::Load,
             ..
-        }) => quotes_are_unremovable(semantic, value),
+        }) => quotes_are_unremovable(semantic, value, settings),
         Expr::Subscript(ast::ExprSubscript { value, slice, .. }) => {
             // for subscripts we don't know whether it's safe to do at runtime
             // since the operation may only be available at type checking time.
@@ -317,18 +338,32 @@ fn quotes_are_unremovable(semantic: &SemanticModel, expr: &Expr) -> bool {
             if !semantic.in_type_checking_block() {
                 return true;
             }
-            quotes_are_unremovable(semantic, value) || quotes_are_unremovable(semantic, slice)
+            if quotes_are_unremovable(semantic, value, settings) {
+                return true;
+            }
+            // for `typing.Annotated`, only analyze the first argument, since the rest may
+            // contain arbitrary expressions.
+            if let Some(qualified_name) = semantic.resolve_qualified_name(value) {
+                if semantic.match_typing_qualified_name(&qualified_name, "Annotated") {
+                    if let Expr::Tuple(ast::ExprTuple { elts, .. }) = slice.as_ref() {
+                        return !elts.is_empty()
+                            && quotes_are_unremovable(semantic, &elts[0], settings);
+                    }
+                    return false;
+                }
+            }
+            quotes_are_unremovable(semantic, slice, settings)
         }
         Expr::Attribute(ast::ExprAttribute { value, .. }) => {
             // for attributes we also don't know whether it's safe
             if !semantic.in_type_checking_block() {
                 return true;
             }
-            quotes_are_unremovable(semantic, value)
+            quotes_are_unremovable(semantic, value, settings)
         }
         Expr::List(ast::ExprList { elts, .. }) | Expr::Tuple(ast::ExprTuple { elts, .. }) => {
             for elt in elts {
-                if quotes_are_unremovable(semantic, elt) {
+                if quotes_are_unremovable(semantic, elt, settings) {
                     return true;
                 }
             }
