@@ -3,7 +3,7 @@ use std::ops::Range;
 use ruff_diagnostics::{AlwaysFixableViolation, Applicability, Diagnostic, Edit, Fix};
 use ruff_macros::{derive_message_formats, ViolationMetadata};
 use ruff_python_ast::parenthesize::parenthesized_range;
-use ruff_python_ast::{AstNode, Expr, ExprBinOp, ExprCall, Operator};
+use ruff_python_ast::{Expr, ExprBinOp, ExprCall, Operator};
 use ruff_python_semantic::SemanticModel;
 use ruff_python_trivia::CommentRanges;
 use ruff_text_size::{Ranged, TextRange};
@@ -50,7 +50,7 @@ impl AlwaysFixableViolation for PathConstructorCurrentDirectory {
 }
 
 /// PTH201
-pub(crate) fn path_constructor_current_directory(checker: &mut Checker, call: &ExprCall) {
+pub(crate) fn path_constructor_current_directory(checker: &Checker, call: &ExprCall) {
     let applicability = |range| {
         if checker.comment_ranges().intersects(range) {
             Applicability::Unsafe
@@ -112,7 +112,7 @@ pub(crate) fn path_constructor_current_directory(checker: &mut Checker, call: &E
         }),
     };
 
-    checker.diagnostics.push(diagnostic);
+    checker.report_diagnostic(diagnostic);
 }
 
 fn parent_and_next_path_fragment_range(
@@ -134,12 +134,6 @@ fn parent_and_next_path_fragment_range(
 
     Some((
         parent.range(),
-        parenthesized_range(
-            right.into(),
-            parent.as_any_node_ref(),
-            comment_ranges,
-            source,
-        )
-        .unwrap_or(range),
+        parenthesized_range(right.into(), parent.into(), comment_ranges, source).unwrap_or(range),
     ))
 }
