@@ -17,7 +17,7 @@ use crate::rules::flake8_use_pathlib::violations::{
 };
 use crate::settings::types::PythonVersion;
 
-pub(crate) fn replaceable_by_pathlib(checker: &mut Checker, call: &ExprCall) {
+pub(crate) fn replaceable_by_pathlib(checker: &Checker, call: &ExprCall) {
     if let Some(diagnostic_kind) = checker
         .semantic()
         .resolve_qualified_name(&call.func)
@@ -97,8 +97,8 @@ pub(crate) fn replaceable_by_pathlib(checker: &mut Checker, call: &ExprCall) {
             // PTH205
             ["os", "path", "getctime"] => Some(OsPathGetctime.into()),
             // PTH123
-            ["" | "builtin", "open"] => {
-                // `closefd` and `openener` are not supported by pathlib, so check if they are
+            ["" | "builtins", "open"] => {
+                // `closefd` and `opener` are not supported by pathlib, so check if they are
                 // are set to non-default values.
                 // https://github.com/astral-sh/ruff/issues/7620
                 // Signature as of Python 3.11 (https://docs.python.org/3/library/functions.html#open):
@@ -163,7 +163,7 @@ pub(crate) fn replaceable_by_pathlib(checker: &mut Checker, call: &ExprCall) {
         let diagnostic = Diagnostic::new::<DiagnosticKind>(diagnostic_kind, call.func.range());
 
         if checker.enabled(diagnostic.kind.rule()) {
-            checker.diagnostics.push(diagnostic);
+            checker.report_diagnostic(diagnostic);
         }
     }
 }
