@@ -49,7 +49,7 @@ impl Violation for InvalidMockAccess {
 }
 
 /// PGH005
-pub(crate) fn uncalled_mock_method(checker: &mut Checker, expr: &Expr) {
+pub(crate) fn uncalled_mock_method(checker: &Checker, expr: &Expr) {
     if let Expr::Attribute(ast::ExprAttribute { attr, .. }) = expr {
         if matches!(
             attr.as_str(),
@@ -61,7 +61,7 @@ pub(crate) fn uncalled_mock_method(checker: &mut Checker, expr: &Expr) {
                 | "assert_has_calls"
                 | "assert_not_called"
         ) {
-            checker.diagnostics.push(Diagnostic::new(
+            checker.report_diagnostic(Diagnostic::new(
                 InvalidMockAccess {
                     reason: Reason::UncalledMethod(attr.to_string()),
                 },
@@ -72,7 +72,7 @@ pub(crate) fn uncalled_mock_method(checker: &mut Checker, expr: &Expr) {
 }
 
 /// PGH005
-pub(crate) fn non_existent_mock_method(checker: &mut Checker, test: &Expr) {
+pub(crate) fn non_existent_mock_method(checker: &Checker, test: &Expr) {
     let attr = match test {
         Expr::Attribute(ast::ExprAttribute { attr, .. }) => attr,
         Expr::Call(ast::ExprCall { func, .. }) => match func.as_ref() {
@@ -90,7 +90,7 @@ pub(crate) fn non_existent_mock_method(checker: &mut Checker, test: &Expr) {
             | "has_calls"
             | "not_called"
     ) {
-        checker.diagnostics.push(Diagnostic::new(
+        checker.report_diagnostic(Diagnostic::new(
             InvalidMockAccess {
                 reason: Reason::NonExistentMethod(attr.to_string()),
             },
