@@ -76,11 +76,7 @@ impl Violation for NonPEP585Annotation {
 }
 
 /// UP006
-pub(crate) fn use_pep585_annotation(
-    checker: &mut Checker,
-    expr: &Expr,
-    replacement: &ModuleMember,
-) {
+pub(crate) fn use_pep585_annotation(checker: &Checker, expr: &Expr, replacement: &ModuleMember) {
     let Some(from) = UnqualifiedName::from_expr(expr) else {
         return;
     };
@@ -136,5 +132,5 @@ pub(crate) fn use_pep585_annotation(
             }
         }
     }
-    checker.diagnostics.push(diagnostic);
+    checker.report_diagnostic(diagnostic);
 }
