@@ -1,6 +1,6 @@
 use ruff_diagnostics::{Diagnostic, Edit, Fix, FixAvailability, Violation};
 use ruff_macros::{derive_message_formats, ViolationMetadata};
-use ruff_python_ast::ExprSubscript;
+use ruff_python_ast::{Expr, ExprSubscript};
 use ruff_python_semantic::SemanticModel;
 
 use crate::{checkers::ast::Checker, settings::types::PythonVersion};
@@ -52,7 +52,7 @@ impl Violation for NonPEP646Unpack {
 }
 
 /// UP044
-pub(crate) fn use_pep646_unpack(checker: &mut Checker, expr: &ExprSubscript) {
+pub(crate) fn use_pep646_unpack(checker: &Checker, expr: &ExprSubscript) {
     if checker.settings.target_version < PythonVersion::Py311 {
         return;
     }
@@ -93,7 +93,7 @@ pub(crate) fn use_pep646_unpack(checker: &mut Checker, expr: &ExprSubscript) {
         format!("*{}", checker.locator().slice(slice.as_ref())),
         *range,
     )));
-    checker.diagnostics.push(diagnostic);
+    checker.report_diagnostic(diagnostic);
 }
 
 /// Determine whether the [`ExprSubscript`] is in a subscript index (e.g., `Generic[Unpack[int]]`).
@@ -117,7 +117,7 @@ fn in_subscript_index(expr: &ExprSubscript, semantic: &SemanticModel) -> bool {
     }
 
     // E.g., `Generic[DType, Unpack[int]]`.
-    if parent.slice.as_tuple_expr().map_or(false, |slice| {
+    if parent.slice.as_tuple_expr().is_some_and(|slice| {
         slice
             .elts
             .iter()
@@ -142,7 +142,7 @@ fn in_vararg(expr: &ExprSubscript, semantic: &SemanticModel) -> bool {
         .parameters
         .vararg
         .as_ref()
-        .and_then(|vararg| vararg.annotation.as_ref())
-        .and_then(|annotation| annotation.as_subscript_expr())
-        .map_or(false, |annotation| annotation == expr)
+        .and_then(|vararg| vararg.annotation())
+        .and_then(Expr::as_subscript_expr)
+        == Some(expr)
 }
