@@ -2,6 +2,7 @@ pub(crate) use bit_count::*;
 pub(crate) use check_and_remove_from_set::*;
 pub(crate) use delete_full_slice::*;
 pub(crate) use for_loop_set_mutations::*;
+pub(crate) use for_loop_writes::*;
 pub(crate) use fstring_number_format::*;
 pub(crate) use hardcoded_string_charset::*;
 pub(crate) use hashlib_digest_hex::*;
@@ -37,9 +38,11 @@ mod bit_count;
 mod check_and_remove_from_set;
 mod delete_full_slice;
 mod for_loop_set_mutations;
+mod for_loop_writes;
 mod fstring_number_format;
 mod hardcoded_string_charset;
 mod hashlib_digest_hex;
+mod helpers;
 mod if_exp_instead_of_or_operator;
 mod if_expr_min_max;
 mod implicit_cwd;
