@@ -51,7 +51,7 @@ impl Violation for ReadWholeFile {
 }
 
 /// FURB101
-pub(crate) fn read_whole_file(checker: &mut Checker, with: &ast::StmtWith) {
+pub(crate) fn read_whole_file(checker: &Checker, with: &ast::StmtWith) {
     // `async` check here is more of a precaution.
     if with.is_async {
         return;
@@ -88,7 +88,7 @@ pub(crate) fn read_whole_file(checker: &mut Checker, with: &ast::StmtWith) {
             )
         })
         .collect();
-    checker.diagnostics.extend(diagnostics);
+    checker.report_diagnostics(diagnostics);
 }
 
 /// AST visitor that matches `open` operations with the corresponding `read` calls.
