@@ -2,6 +2,7 @@ pub(crate) use ambiguous_unicode_character::*;
 pub(crate) use assert_with_print_message::*;
 pub(crate) use assignment_in_assert::*;
 pub(crate) use asyncio_dangling_task::*;
+pub(crate) use class_with_mixed_type_vars::*;
 pub(crate) use collection_literal_concatenation::*;
 pub(crate) use dataclass_enum::*;
 pub(crate) use decimal_from_float_literal::*;
@@ -12,6 +13,7 @@ pub(crate) use function_call_in_dataclass_default::*;
 pub(crate) use if_key_in_dict_del::*;
 pub(crate) use implicit_optional::*;
 pub(crate) use incorrectly_parenthesized_tuple_in_subscript::*;
+pub(crate) use indented_form_feed::*;
 pub(crate) use invalid_assert_message_literal_argument::*;
 pub(crate) use invalid_formatter_suppression_comment::*;
 pub(crate) use invalid_index_type::*;
@@ -21,6 +23,7 @@ pub(crate) use missing_fstring_syntax::*;
 pub(crate) use mutable_class_default::*;
 pub(crate) use mutable_dataclass_default::*;
 pub(crate) use mutable_fromkeys_value::*;
+pub(crate) use needless_else::*;
 pub(crate) use never_union::*;
 pub(crate) use none_not_at_end_of_union::*;
 pub(crate) use parenthesize_chained_operators::*;
@@ -31,6 +34,7 @@ pub(crate) use redirected_noqa::*;
 pub(crate) use redundant_bool_literal::*;
 pub(crate) use sort_dunder_all::*;
 pub(crate) use sort_dunder_slots::*;
+pub(crate) use starmap_zip::*;
 pub(crate) use static_key_dict_comprehension::*;
 #[cfg(any(feature = "test-rules", test))]
 pub(crate) use test_rules::*;
@@ -53,6 +57,7 @@ mod ambiguous_unicode_character;
 mod assert_with_print_message;
 mod assignment_in_assert;
 mod asyncio_dangling_task;
+mod class_with_mixed_type_vars;
 mod collection_literal_concatenation;
 mod confusables;
 mod dataclass_enum;
@@ -65,6 +70,7 @@ mod helpers;
 mod if_key_in_dict_del;
 mod implicit_optional;
 mod incorrectly_parenthesized_tuple_in_subscript;
+mod indented_form_feed;
 mod invalid_assert_message_literal_argument;
 mod invalid_formatter_suppression_comment;
 mod invalid_index_type;
@@ -74,6 +80,7 @@ mod missing_fstring_syntax;
 mod mutable_class_default;
 mod mutable_dataclass_default;
 mod mutable_fromkeys_value;
+mod needless_else;
 mod never_union;
 mod none_not_at_end_of_union;
 mod parenthesize_chained_operators;
@@ -85,6 +92,7 @@ mod redundant_bool_literal;
 mod sequence_sorting;
 mod sort_dunder_all;
 mod sort_dunder_slots;
+mod starmap_zip;
 mod static_key_dict_comprehension;
 mod suppression_comment_visitor;
 #[cfg(any(feature = "test-rules", test))]
