@@ -710,3 +710,24 @@ f'{x:a{y=:{z:hy "user"}}} \'\'\''
 f"""{1=: "this" is fine}"""
 f'''{1=: "this" is fine}'''  # Change quotes to double quotes because they're preferred
 f'{1=: {'ab"cd"'}}'  # It's okay if the quotes are in an expression part.
+
+
+# Regression tests for https://github.com/astral-sh/ruff/issues/15459
+print(f"{ {1, 2, 3} - {2} }")
+print(f"{ {1: 2}.keys() }")
+print(f"{({1, 2, 3}) - ({2})}")
+print(f"{1, 2, {3} }")
+print(f"{(1, 2, {3})}")
+
+
+# Regression tests for https://github.com/astral-sh/ruff/issues/15535
+print(f"{ {}, }")  # A single item tuple gets parenthesized
+print(f"{ {}.values(), }")
+print(f"{ {}, 1 }")  # A tuple with multiple elements doesn't get parenthesized
+print(f"{  # Tuple with multiple elements that doesn't fit on a single line gets parenthesized
+    {}, 1,
+}")
+
+
+# Regression tests for https://github.com/astral-sh/ruff/issues/15536
+print(f"{ {}, 1, }")
