@@ -1,15 +1,14 @@
 use ruff_python_ast::{AnyNodeRef, ExprFString, StringLike};
-use ruff_text_size::TextSlice;
 
 use crate::expression::parentheses::{
     in_parentheses_only_group, NeedsParentheses, OptionalParentheses,
 };
-use crate::other::f_string::{FStringLayout, FormatFString};
+use crate::other::f_string::FStringLayout;
 use crate::prelude::*;
 use crate::string::implicit::{
     FormatImplicitConcatenatedString, FormatImplicitConcatenatedStringFlat,
 };
-use crate::string::{Quoting, StringLikeExtensions};
+use crate::string::StringLikeExtensions;
 
 #[derive(Default)]
 pub struct FormatExprFString;
@@ -23,7 +22,7 @@ impl FormatNodeRule<ExprFString> for FormatExprFString {
             // [`ruff_python_ast::FStringValue::single`] constructor.
             let f_string = f_string_part.as_f_string().unwrap();
 
-            FormatFString::new(f_string, f_string_quoting(item, f.context().source())).fmt(f)
+            f_string.format().fmt(f)
         } else {
             // Always join fstrings that aren't parenthesized and thus, are always on a single line.
             if !f.context().node_level().is_parenthesized() {
@@ -58,28 +57,3 @@ impl NeedsParentheses for ExprFString {
         }
     }
 }
-
-pub(crate) fn f_string_quoting(f_string: &ExprFString, source: &str) -> Quoting {
-    let unprefixed = source
-        .slice(f_string)
-        .trim_start_matches(|c| c != '"' && c != '\'');
-    let triple_quoted = unprefixed.starts_with(r#"""""#) || unprefixed.starts_with(r"'''");
-
-    if f_string
-        .value
-        .elements()
-        .filter_map(|element| element.as_expression())
-        .any(|expression| {
-            let string_content = source.slice(expression);
-            if triple_quoted {
-                string_content.contains(r#"""""#) || string_content.contains("'''")
-            } else {
-                string_content.contains(['"', '\''])
-            }
-        })
-    {
-        Quoting::Preserve
-    } else {
-        Quoting::CanChange
-    }
-}
