@@ -5,8 +5,9 @@ use std::iter::FusedIterator;
 use ruff_formatter::FormatContext;
 use ruff_python_ast::visitor::source_order::SourceOrderVisitor;
 use ruff_python_ast::{
-    str::Quote, AnyStringFlags, BytesLiteral, FString, FStringElement, FStringElements,
-    FStringFlags, StringFlags, StringLikePart, StringLiteral,
+    str::{Quote, TripleQuotes},
+    AnyStringFlags, BytesLiteral, FString, FStringElement, FStringElements, FStringFlags,
+    StringFlags, StringLikePart, StringLiteral,
 };
 use ruff_text_size::{Ranged, TextRange, TextSlice};
 
@@ -44,15 +45,33 @@ impl<'a, 'src> StringNormalizer<'a, 'src> {
         let preferred_quote_style = self
             .preferred_quote_style
             .unwrap_or(self.context.options().quote_style());
+        let supports_pep_701 = self.context.options().target_version().supports_pep_701();
 
+        // For f-strings prefer alternating the quotes unless The outer string is triple quoted and the inner isn't.
+        if let FStringState::InsideExpressionElement(parent_context) = self.context.f_string_state()
+        {
+            let parent_flags = parent_context.f_string().flags();
+
+            if !parent_flags.is_triple_quoted() || string.flags().is_triple_quoted() {
+                // This logic is even necessary when using preserve and the target python version doesn't support PEP701 because
+                // we might end up joining two f-strings that have different quote styles, in which case we need to alternate the quotes
+                // for inner strings to avoid a syntax error: `string = "this is my string with " f'"{params.get("mine")}"'`
+                if !preferred_quote_style.is_preserve() || !supports_pep_701 {
+                    return QuoteStyle::from(parent_flags.quote_style().opposite());
+                }
+            }
+        }
+
+        // Leave the quotes unchanged for all other strings.
         if preferred_quote_style.is_preserve() {
             return QuoteStyle::Preserve;
         }
 
+        // There are cases where it is necessary to preserve the quotes to prevent an invalid f-string.
         if let StringLikePart::FString(fstring) = string {
             // There are two cases where it's necessary to preserve the quotes if the
             // target version is pre 3.12 and the part is an f-string.
-            if !self.context.options().target_version().supports_pep_701() {
+            if !supports_pep_701 {
                 // An f-string expression contains a debug text with a quote character
                 // because the formatter will emit the debug expression **exactly** the
                 // same as in the source text.
@@ -77,16 +96,6 @@ impl<'a, 'src> StringNormalizer<'a, 'src> {
             }
         }
 
-        // For f-strings prefer alternating the quotes unless The outer string is triple quoted and the inner isn't.
-        if let FStringState::InsideExpressionElement(parent_context) = self.context.f_string_state()
-        {
-            let parent_flags = parent_context.f_string().flags();
-
-            if !parent_flags.is_triple_quoted() || string.flags().is_triple_quoted() {
-                return QuoteStyle::from(parent_flags.quote_style().opposite());
-            }
-        }
-
         // Per PEP 8, always prefer double quotes for triple-quoted strings.
         if string.flags().is_triple_quoted() {
             // ... unless we're formatting a code snippet inside a docstring,
@@ -265,7 +274,7 @@ impl QuoteMetadata {
 
     pub(crate) fn from_str(text: &str, flags: AnyStringFlags, preferred_quote: Quote) -> Self {
         let kind = if flags.is_raw_string() {
-            QuoteMetadataKind::raw(text, preferred_quote, flags.is_triple_quoted())
+            QuoteMetadataKind::raw(text, preferred_quote, flags.triple_quotes())
         } else if flags.is_triple_quoted() {
             QuoteMetadataKind::triple_quoted(text, preferred_quote)
         } else {
@@ -520,7 +529,7 @@ impl QuoteMetadataKind {
 
     /// Computes if a raw string uses the preferred quote. If it does, then it's not possible
     /// to change the quote style because it would require escaping which isn't possible in raw strings.
-    fn raw(text: &str, preferred: Quote, triple_quoted: bool) -> Self {
+    fn raw(text: &str, preferred: Quote, triple_quotes: TripleQuotes) -> Self {
         let mut chars = text.chars().peekable();
         let preferred_quote_char = preferred.as_char();
 
@@ -532,7 +541,7 @@ impl QuoteMetadataKind {
                 }
                 // `"` or `'`
                 Some(c) if c == preferred_quote_char => {
-                    if !triple_quoted {
+                    if triple_quotes.is_no() {
                         break true;
                     }
 
@@ -1049,7 +1058,7 @@ mod tests {
     use std::borrow::Cow;
 
     use ruff_python_ast::{
-        str::Quote,
+        str::{Quote, TripleQuotes},
         str_prefix::{AnyStringPrefix, ByteStringPrefix},
         AnyStringFlags,
     };
@@ -1078,7 +1087,7 @@ mod tests {
             AnyStringFlags::new(
                 AnyStringPrefix::Bytes(ByteStringPrefix::Regular),
                 Quote::Double,
-                false,
+                TripleQuotes::No,
             ),
             false,
         );
