@@ -177,12 +177,9 @@ fn format() {
     let test_file = |input_path: &Path| {
         let content = fs::read_to_string(input_path).unwrap();
 
-        let options = PyFormatOptions::from_extension(input_path);
-        let formatted_code = format_file(&content, &options, input_path);
-
         let mut snapshot = format!("## Input\n{}", CodeFrame::new("python", &content));
-
         let options_path = input_path.with_extension("options.json");
+
         if let Ok(options_file) = fs::File::open(options_path) {
             let reader = BufReader::new(options_file);
             let options: Vec<PyFormatOptions> =
@@ -228,6 +225,9 @@ fn format() {
             }
         } else {
             // We want to capture the differences in the preview style in our fixtures
+            let options = PyFormatOptions::from_extension(input_path);
+            let formatted_code = format_file(&content, &options, input_path);
+
             let options_preview = options.with_preview(PreviewMode::Enabled);
             let formatted_preview = format_file(&content, &options_preview, input_path);
 
@@ -391,13 +391,15 @@ fn ensure_unchanged_ast(
 
     // Parse the unformatted code.
     let mut unformatted_ast = parse(unformatted_code, source_type.as_mode())
-        .expect("Unformatted code to be valid syntax");
+        .expect("Unformatted code to be valid syntax")
+        .into_syntax();
     Normalizer.visit_module(&mut unformatted_ast);
     let unformatted_ast = ComparableMod::from(&unformatted_ast);
 
     // Parse the formatted code.
-    let mut formatted_ast =
-        parse(formatted_code, source_type.as_mode()).expect("Formatted code to be valid syntax");
+    let mut formatted_ast = parse(formatted_code, source_type.as_mode())
+        .expect("Formatted code to be valid syntax")
+        .into_syntax();
     Normalizer.visit_module(&mut formatted_ast);
     let formatted_ast = ComparableMod::from(&formatted_ast);
 
