@@ -8,33 +8,37 @@ use crate::SemanticModel;
 /// import sys
 ///
 /// sys.path.append("../")
+/// sys.path += ["../"]
 /// ```
 pub fn is_sys_path_modification(stmt: &Stmt, semantic: &SemanticModel) -> bool {
-    let Stmt::Expr(ast::StmtExpr { value, range: _ }) = stmt else {
-        return false;
-    };
-    let Expr::Call(ast::ExprCall { func, .. }) = value.as_ref() else {
-        return false;
-    };
-    semantic
-        .resolve_qualified_name(func.as_ref())
-        .is_some_and(|qualified_name| {
-            matches!(
-                qualified_name.segments(),
-                [
-                    "sys",
-                    "path",
-                    "append"
-                        | "insert"
-                        | "extend"
-                        | "remove"
-                        | "pop"
-                        | "clear"
-                        | "reverse"
-                        | "sort"
-                ]
-            )
-        })
+    match stmt {
+        Stmt::Expr(ast::StmtExpr { value, range: _ }) => match value.as_ref() {
+            Expr::Call(ast::ExprCall { func, .. }) => semantic
+                .resolve_qualified_name(func.as_ref())
+                .is_some_and(|qualified_name| {
+                    matches!(
+                        qualified_name.segments(),
+                        [
+                            "sys",
+                            "path",
+                            "append"
+                                | "insert"
+                                | "extend"
+                                | "remove"
+                                | "pop"
+                                | "clear"
+                                | "reverse"
+                                | "sort"
+                        ]
+                    )
+                }),
+            _ => false,
+        },
+        Stmt::AugAssign(ast::StmtAugAssign { target, .. }) => semantic
+            .resolve_qualified_name(map_subscript(target))
+            .is_some_and(|qualified_name| matches!(qualified_name.segments(), ["sys", "path"])),
+        _ => false,
+    }
 }
 
 /// Returns `true` if a [`Stmt`] is an `os.environ` modification, as in:
