@@ -2,7 +2,7 @@ use anyhow::Context;
 use lsp_types::{self as types, request as req, Range};
 
 use crate::edit::{RangeExt, ToRangeExt};
-use crate::resolve::is_document_excluded;
+use crate::resolve::is_document_excluded_for_formatting;
 use crate::server::api::LSPResult;
 use crate::server::{client::Notifier, Result};
 use crate::session::{DocumentQuery, DocumentSnapshot};
@@ -46,16 +46,14 @@ fn format_text_document_range(
     query: &DocumentQuery,
     encoding: PositionEncoding,
 ) -> Result<super::FormatResponse> {
-    let file_resolver_settings = query.settings().file_resolver();
-    let formatter_settings = query.settings().formatter();
+    let settings = query.settings();
 
     // If the document is excluded, return early.
     if let Some(file_path) = query.file_path() {
-        if is_document_excluded(
+        if is_document_excluded_for_formatting(
             &file_path,
-            file_resolver_settings,
-            None,
-            Some(formatter_settings),
+            &settings.file_resolver,
+            &settings.formatter,
             text_document.language_id(),
         ) {
             return Ok(None);
@@ -68,7 +66,7 @@ fn format_text_document_range(
     let formatted_range = crate::format::format_range(
         text_document,
         query.source_type(),
-        formatter_settings,
+        &settings.formatter,
         range,
     )
     .with_failure_code(lsp_server::ErrorCode::InternalError)?;
