@@ -16,16 +16,18 @@ export default function PrimarySideBar({
     <SideBar position="left">
       <SideBarEntry
         title="Source"
+        position={"left"}
         onClick={() => onSelectTool("Source")}
-        selected={selected == "Source"}
+        selected={selected === "Source"}
       >
         <FileIcon />
       </SideBarEntry>
 
       <SideBarEntry
         title="Settings"
+        position={"left"}
         onClick={() => onSelectTool("Settings")}
-        selected={selected == "Settings"}
+        selected={selected === "Settings"}
       >
         <SettingsIcon />
       </SideBarEntry>
